@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2012 by Dominique Dumont.
+# This software is Copyright (c) 2014 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -57,7 +57,6 @@
                 summary    => "Override Config::Model::Value:",
                 description =>
                   "Perl class name of a child of Config::Model::Value",
-                experience => 'master',
                 'warp'     => {
                     follow  => { 't'            => '- type' },
                     'rules' => [ '$t eq "leaf"' => { level => 'normal', } ]
@@ -114,7 +113,6 @@
                 type       => 'leaf',
                 level      => 'hidden',
                 value_type => 'uniline',
-                experience => 'advanced',
                 warp       => {
                     follow => {
                         t  => '- type',
@@ -139,7 +137,6 @@
                     vt => '- value_type',
                 },
                 level      => 'hidden',
-                experience => 'master',
                 'rules'    => [
                     '$t  eq "check_list" or $vt eq "reference"' => {
                         level             => 'normal',
@@ -159,7 +156,6 @@
                 type       => 'leaf',
                 level      => 'hidden',
                 value_type => 'uniline',
-                experience => 'advanced',
                 warp       => {
                     follow  => { t               => '- type' },
                     'rules' => [ '$t  eq "leaf"' => { level => 'important', }, ]
@@ -174,7 +170,6 @@
             'compute' => {
                 type       => 'warped_node',
                 level      => 'hidden',
-                experience => 'advanced',
 
                 follow  => { t => '- type', },
                 'rules' => [
@@ -191,7 +186,6 @@
             'migrate_from' => {
                 type       => 'warped_node',
                 level      => 'hidden',
-                experience => 'advanced',
 
                 follow  => { t => '- type', },
                 'rules' => [
@@ -229,7 +223,6 @@
                 type       => 'leaf',
                 level      => 'hidden',
                 value_type => 'uniline',
-                experience => 'advanced',
                 warp       => {
                     follow  => { 't'                            => '?type' },
                     'rules' => [ '$t eq "hash" or $t eq "list"' => { level => 'normal', } ]
@@ -244,7 +237,6 @@
                 type       => 'leaf',
                 level      => 'hidden',
                 value_type => 'uniline',
-                experience => 'advanced',
                 warp       => {
                     follow  => { 't'            => '?type' },
                     'rules' => [ '$t eq "hash"' => { level => 'normal', } ]
